@@ -224,6 +224,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                             "minimum": 0,
                             "type": "integer"
                         },
+                        "plan_orders_count": {
+                            "format": "int32",
+                            "maximum": 9000,
+                            "minimum": 0,
+                            "type": "integer"
+                        },
                         "quality": {
                             "additionalProperties": false,
                             "nullable": true,
@@ -349,6 +355,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                             "format": "double",
                             "minimum": 0,
                             "type": "number"
+                        },
+                        "waitlist_orders_count": {
+                            "format": "int32",
+                            "maximum": 9000,
+                            "minimum": 0,
+                            "type": "integer"
                         }
                     },
                     "required": [
@@ -597,6 +609,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                         "minimum": 0,
                                         "type": "integer"
                                     },
+                                    "plan_orders_count": {
+                                        "format": "int32",
+                                        "maximum": 9000,
+                                        "minimum": 0,
+                                        "type": "integer"
+                                    },
                                     "quality": {
                                         "additionalProperties": false,
                                         "nullable": true,
@@ -722,6 +740,12 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                         "format": "double",
                                         "minimum": 0,
                                         "type": "number"
+                                    },
+                                    "waitlist_orders_count": {
+                                        "format": "int32",
+                                        "maximum": 9000,
+                                        "minimum": 0,
+                                        "type": "integer"
                                     }
                                 },
                                 "required": [
@@ -1147,6 +1171,18 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                             "additionalProperties": false,
                             "nullable": false,
                             "properties": {
+                                "attributes": {
+                                    "default": [],
+                                    "items": {
+                                        "maxLength": 10000,
+                                        "minLength": 0,
+                                        "type": "string"
+                                    },
+                                    "maxItems": 1000,
+                                    "minItems": 0,
+                                    "type": "array",
+                                    "uniqueItems": true
+                                },
                                 "cargo_placements": {
                                     "items": {
                                         "additionalProperties": false,
@@ -1177,6 +1213,11 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                     "minLength": 1,
                                     "type": "string"
                                 },
+                                "event_key": {
+                                    "maxLength": 1024,
+                                    "minLength": 1,
+                                    "type": "string"
+                                },
                                 "location_key": {
                                     "maxLength": 1024,
                                     "minLength": 1,
@@ -1270,10 +1311,17 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                         "minItems": 2,
                         "type": "array"
                     },
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
                     },
                     "finish_location_key": {
                         "maxLength": 1024,
@@ -1321,6 +1369,18 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                         "additionalProperties": false,
                         "nullable": false,
                         "properties": {
+                            "attributes": {
+                                "default": [],
+                                "items": {
+                                    "maxLength": 10000,
+                                    "minLength": 0,
+                                    "type": "string"
+                                },
+                                "maxItems": 1000,
+                                "minItems": 0,
+                                "type": "array",
+                                "uniqueItems": true
+                            },
                             "cargos": {
                                 "items": {
                                     "additionalProperties": false,
@@ -1368,6 +1428,30 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                             },
                                             "type": "object"
                                         },
+                                        "cargo_features": {
+                                            "default": [],
+                                            "items": {
+                                                "maxLength": 256,
+                                                "minLength": 1,
+                                                "type": "string"
+                                            },
+                                            "maxItems": 1000,
+                                            "minItems": 0,
+                                            "type": "array",
+                                            "uniqueItems": true
+                                        },
+                                        "cargo_restrictions": {
+                                            "default": [],
+                                            "items": {
+                                                "maxLength": 256,
+                                                "minLength": 1,
+                                                "type": "string"
+                                            },
+                                            "maxItems": 1000,
+                                            "minItems": 0,
+                                            "type": "array",
+                                            "uniqueItems": true
+                                        },
                                         "height": {
                                             "default": 0,
                                             "format": "double",
@@ -1440,20 +1524,22 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                 "minItems": 0,
                                 "type": "array"
                             },
-                            "comment": {
-                                "maxLength": 10000,
-                                "minLength": 0,
-                                "type": "string"
-                            },
                             "demands": {
                                 "items": {
                                     "additionalProperties": false,
                                     "nullable": false,
                                     "properties": {
-                                        "comment": {
-                                            "maxLength": 10000,
-                                            "minLength": 0,
-                                            "type": "string"
+                                        "attributes": {
+                                            "default": [],
+                                            "items": {
+                                                "maxLength": 10000,
+                                                "minLength": 0,
+                                                "type": "string"
+                                            },
+                                            "maxItems": 1000,
+                                            "minItems": 0,
+                                            "type": "array",
+                                            "uniqueItems": true
                                         },
                                         "demand_type": {
                                             "enum": [
@@ -1481,13 +1567,18 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                                         "minimum": 0,
                                                         "type": "integer"
                                                     },
+                                                    "key": {
+                                                        "maxLength": 1024,
+                                                        "minLength": 1,
+                                                        "type": "string"
+                                                    },
                                                     "location_key": {
                                                         "maxLength": 1024,
                                                         "minLength": 1,
                                                         "type": "string"
                                                     },
                                                     "reward": {
-                                                        "default": 1000,
+                                                        "default": 1000.1,
                                                         "format": "double",
                                                         "maximum": 1000000,
                                                         "minimum": 0,
