@@ -10,10 +10,17 @@ PREDICT_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
                     },
                     "key": {
                         "maxLength": 1024,
@@ -119,6 +126,18 @@ PREDICT_TASK_SCHEMA = '''{
             "additionalProperties": false,
             "nullable": false,
             "properties": {
+                "attributes": {
+                    "default": [],
+                    "items": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
+                    "maxItems": 1000,
+                    "minItems": 0,
+                    "type": "array",
+                    "uniqueItems": true
+                },
                 "cargos": {
                     "items": {
                         "additionalProperties": false,
@@ -166,6 +185,30 @@ PREDICT_TASK_SCHEMA = '''{
                                 },
                                 "type": "object"
                             },
+                            "cargo_features": {
+                                "default": [],
+                                "items": {
+                                    "maxLength": 256,
+                                    "minLength": 1,
+                                    "type": "string"
+                                },
+                                "maxItems": 1000,
+                                "minItems": 0,
+                                "type": "array",
+                                "uniqueItems": true
+                            },
+                            "cargo_restrictions": {
+                                "default": [],
+                                "items": {
+                                    "maxLength": 256,
+                                    "minLength": 1,
+                                    "type": "string"
+                                },
+                                "maxItems": 1000,
+                                "minItems": 0,
+                                "type": "array",
+                                "uniqueItems": true
+                            },
                             "height": {
                                 "default": 0,
                                 "format": "double",
@@ -238,20 +281,22 @@ PREDICT_TASK_SCHEMA = '''{
                     "minItems": 0,
                     "type": "array"
                 },
-                "comment": {
-                    "maxLength": 10000,
-                    "minLength": 0,
-                    "type": "string"
-                },
                 "demands": {
                     "items": {
                         "additionalProperties": false,
                         "nullable": false,
                         "properties": {
-                            "comment": {
-                                "maxLength": 10000,
-                                "minLength": 0,
-                                "type": "string"
+                            "attributes": {
+                                "default": [],
+                                "items": {
+                                    "maxLength": 10000,
+                                    "minLength": 0,
+                                    "type": "string"
+                                },
+                                "maxItems": 1000,
+                                "minItems": 0,
+                                "type": "array",
+                                "uniqueItems": true
                             },
                             "demand_type": {
                                 "enum": [
@@ -279,13 +324,18 @@ PREDICT_TASK_SCHEMA = '''{
                                             "minimum": 0,
                                             "type": "integer"
                                         },
+                                        "key": {
+                                            "maxLength": 1024,
+                                            "minLength": 1,
+                                            "type": "string"
+                                        },
                                         "location_key": {
                                             "maxLength": 1024,
                                             "minLength": 1,
                                             "type": "string"
                                         },
                                         "reward": {
-                                            "default": 1000,
+                                            "default": 1000.1,
                                             "format": "double",
                                             "maximum": 1000000,
                                             "minimum": 0,
