@@ -55,10 +55,17 @@ VALIDATE_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
                     },
                     "key": {
                         "maxLength": 1024,
@@ -165,6 +172,18 @@ VALIDATE_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
+                    },
                     "cargos": {
                         "items": {
                             "additionalProperties": false,
@@ -212,6 +231,30 @@ VALIDATE_TASK_SCHEMA = '''{
                                     },
                                     "type": "object"
                                 },
+                                "cargo_features": {
+                                    "default": [],
+                                    "items": {
+                                        "maxLength": 256,
+                                        "minLength": 1,
+                                        "type": "string"
+                                    },
+                                    "maxItems": 1000,
+                                    "minItems": 0,
+                                    "type": "array",
+                                    "uniqueItems": true
+                                },
+                                "cargo_restrictions": {
+                                    "default": [],
+                                    "items": {
+                                        "maxLength": 256,
+                                        "minLength": 1,
+                                        "type": "string"
+                                    },
+                                    "maxItems": 1000,
+                                    "minItems": 0,
+                                    "type": "array",
+                                    "uniqueItems": true
+                                },
                                 "height": {
                                     "default": 0,
                                     "format": "double",
@@ -284,20 +327,22 @@ VALIDATE_TASK_SCHEMA = '''{
                         "minItems": 0,
                         "type": "array"
                     },
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
-                    },
                     "demands": {
                         "items": {
                             "additionalProperties": false,
                             "nullable": false,
                             "properties": {
-                                "comment": {
-                                    "maxLength": 10000,
-                                    "minLength": 0,
-                                    "type": "string"
+                                "attributes": {
+                                    "default": [],
+                                    "items": {
+                                        "maxLength": 10000,
+                                        "minLength": 0,
+                                        "type": "string"
+                                    },
+                                    "maxItems": 1000,
+                                    "minItems": 0,
+                                    "type": "array",
+                                    "uniqueItems": true
                                 },
                                 "demand_type": {
                                     "enum": [
@@ -325,13 +370,18 @@ VALIDATE_TASK_SCHEMA = '''{
                                                 "minimum": 0,
                                                 "type": "integer"
                                             },
+                                            "key": {
+                                                "maxLength": 1024,
+                                                "minLength": 1,
+                                                "type": "string"
+                                            },
                                             "location_key": {
                                                 "maxLength": 1024,
                                                 "minLength": 1,
                                                 "type": "string"
                                             },
                                             "reward": {
-                                                "default": 1000,
+                                                "default": 1000.1,
                                                 "format": "double",
                                                 "maximum": 1000000,
                                                 "minimum": 0,
@@ -488,10 +538,17 @@ VALIDATE_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
                     },
                     "key": {
                         "maxLength": 1024,
@@ -931,6 +988,18 @@ VALIDATE_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
+                    },
                     "availability_time": {
                         "additionalProperties": false,
                         "properties": {
@@ -949,11 +1018,6 @@ VALIDATE_TASK_SCHEMA = '''{
                         ],
                         "type": "object"
                     },
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
-                    },
                     "finish_location_key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -1067,6 +1131,18 @@ VALIDATE_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
+                    },
                     "boxes": {
                         "items": {
                             "additionalProperties": false,
@@ -1203,17 +1279,13 @@ VALIDATE_TASK_SCHEMA = '''{
                         "minItems": 1,
                         "type": "array"
                     },
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
-                    },
                     "key": {
                         "maxLength": 1024,
                         "minLength": 1,
                         "type": "string"
                     },
                     "performer_restrictions": {
+                        "default": [],
                         "items": {
                             "maxLength": 256,
                             "minLength": 1,
@@ -1269,6 +1341,18 @@ VALIDATE_TASK_SCHEMA = '''{
                             "additionalProperties": false,
                             "nullable": false,
                             "properties": {
+                                "attributes": {
+                                    "default": [],
+                                    "items": {
+                                        "maxLength": 10000,
+                                        "minLength": 0,
+                                        "type": "string"
+                                    },
+                                    "maxItems": 1000,
+                                    "minItems": 0,
+                                    "type": "array",
+                                    "uniqueItems": true
+                                },
                                 "cargo_placements": {
                                     "items": {
                                         "additionalProperties": false,
@@ -1299,6 +1383,11 @@ VALIDATE_TASK_SCHEMA = '''{
                                     "minLength": 1,
                                     "type": "string"
                                 },
+                                "event_key": {
+                                    "maxLength": 1024,
+                                    "minLength": 1,
+                                    "type": "string"
+                                },
                                 "location_key": {
                                     "maxLength": 1024,
                                     "minLength": 1,
@@ -1392,10 +1481,17 @@ VALIDATE_TASK_SCHEMA = '''{
                         "minItems": 2,
                         "type": "array"
                     },
-                    "comment": {
-                        "maxLength": 10000,
-                        "minLength": 0,
-                        "type": "string"
+                    "attributes": {
+                        "default": [],
+                        "items": {
+                            "maxLength": 10000,
+                            "minLength": 0,
+                            "type": "string"
+                        },
+                        "maxItems": 1000,
+                        "minItems": 0,
+                        "type": "array",
+                        "uniqueItems": true
                     },
                     "finish_location_key": {
                         "maxLength": 1024,
